@@ -113,7 +113,7 @@ def from_map(mapping: t.Mapping[_T, _S], key: _T) -> Maybe[_S]:
     return Nothing
 
 
-def first(maybes: t.Sequence[Maybe[_T]]) -> Maybe[_T]:
+def first(maybes: t.Iterable[Maybe[_T]]) -> Maybe[_T]:
     """Return the first ``Just`` in a sequence.
 
     >>> first([Just(0), Just(1)])
