@@ -53,6 +53,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
         PlagiarismService as _PlagiarismService,
     )
     from codegrade._api.role import RoleService as _RoleService
+    from codegrade._api.section import SectionService as _SectionService
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
     )
@@ -98,6 +99,7 @@ class _BaseClient:
         "__permission",
         "__plagiarism",
         "__role",
+        "__section",
         "__site_settings",
         "__snippet",
         "__sso_provider",
@@ -151,6 +153,7 @@ class _BaseClient:
             "_PlagiarismService[_BaseClientT]"
         ] = None
         self.__role: t.Optional["_RoleService[_BaseClientT]"] = None
+        self.__section: t.Optional["_SectionService[_BaseClientT]"] = None
         self.__site_settings: t.Optional[
             "_SiteSettingsService[_BaseClientT]"
         ] = None
@@ -393,6 +396,15 @@ class _BaseClient:
             self.__role = m.RoleService(self)
         return self.__role
 
+    @property
+    def section(self: _BaseClientT) -> "_SectionService[_BaseClientT]":
+        """Get a :class:`.SectionService` to do requests concerning Section."""
+        if self.__section is None:
+            import codegrade._api.section as m
+
+            self.__section = m.SectionService(self)
+        return self.__section
+
     @property
     def site_settings(
         self: _BaseClientT,
@@ -549,7 +561,7 @@ class AuthenticatedClient(_BaseClient):
         :param username: Your CodeGrade username.
         :param password: Your CodeGrade password, if you do not know your
             password you can set it by following `these steps.
-            <https://help.codegrade.com/for-teachers/setting-up-a-password-for-my-account>`_
+            <https://help.codegrade.com/faq/setting-up-a-password-for-my-account>`_
         :param tenant: The id or name of your tenant in CodeGrade. This is the
             name you click on the login screen.
         :param host: The CodeGrade instance you want to use.
