@@ -25,6 +25,9 @@ from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
 from .assignment_default_grading_scale_setting import (
     AssignmentDefaultGradingScaleSetting,
 )
+from .assignment_description_enabled_setting import (
+    AssignmentDescriptionEnabledSetting,
+)
 from .assignment_done_type import AssignmentDoneType
 from .assignment_export_column import AssignmentExportColumn
 from .assignment_feedback import AssignmentFeedback
@@ -141,6 +144,11 @@ from .base_rubric_item import BaseRubricItem
 from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
 )
+from .bulk_course_registration_link import BulkCourseRegistrationLink
+from .bulk_enroll_course_data import BulkEnrollCourseData
+from .canvas_course_id_copying_enabled_setting import (
+    CanvasCourseIdCopyingEnabledSetting,
+)
 from .cg_ignore_version import CGIgnoreVersion
 from .change_user_role_course_data import ChangeUserRoleCourseData
 from .check_points_as_json import CheckPointsAsJSON
@@ -171,6 +179,14 @@ from .coupon_usage import CouponUsage
 from .coupon_with_code import CouponWithCode
 from .coupon_without_code import CouponWithoutCode
 from .course import Course
+from .course_bulk_enroll_result import CourseBulkEnrollResult
+from .course_bulk_register_enabled_setting import (
+    CourseBulkRegisterEnabledSetting,
+)
+from .course_gradebook_enabled_setting import CourseGradebookEnabledSetting
+from .course_gradebook_render_warning_size_setting import (
+    CourseGradebookRenderWarningSizeSetting,
+)
 from .course_of_course_price import CourseOfCoursePrice
 from .course_perm_map import CoursePermMap
 from .course_permission import CoursePermission
@@ -205,6 +221,8 @@ from .create_snippet_course_data import CreateSnippetCourseData
 from .create_snippet_data import CreateSnippetData
 from .create_sso_provider_data import CreateSSOProviderData
 from .create_tenant_data import CreateTenantData
+from .csv_large_file_limit_setting import CsvLargeFileLimitSetting
+from .csv_too_many_errors_limit_setting import CsvTooManyErrorsLimitSetting
 from .currency import Currency
 from .custom_output_as_json import CustomOutputAsJSON
 from .custom_output_data import CustomOutputData
@@ -226,6 +244,9 @@ from .export_assignment_data import ExportAssignmentData
 from .export_assignment_files_data import ExportAssignmentFilesData
 from .extended_auto_test_result import ExtendedAutoTestResult
 from .extended_auto_test_run import ExtendedAutoTestRun
+from .extended_bulk_course_registration_link import (
+    ExtendedBulkCourseRegistrationLink,
+)
 from .extended_course import ExtendedCourse
 from .extended_course_registration_link import ExtendedCourseRegistrationLink
 from .extended_course_section import ExtendedCourseSection
@@ -372,6 +393,35 @@ from .min_password_score_setting import MinPasswordScoreSetting
 from .mirror_file_result import MirrorFileResult
 from .missing_cookie_error import MissingCookieError
 from .missing_file import MissingFile
+from .new_auto_test_build_max_command_time_setting import (
+    NewAutoTestBuildMaxCommandTimeSetting,
+)
+from .new_auto_test_build_output_limit_setting import (
+    NewAutoTestBuildOutputLimitSetting,
+)
+from .new_auto_test_copying_enabled_setting import (
+    NewAutoTestCopyingEnabledSetting,
+)
+from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
+from .new_auto_test_initial_build_id_setting import (
+    NewAutoTestInitialBuildIdSetting,
+)
+from .new_auto_test_max_dynamodb_size_setting import (
+    NewAutoTestMaxDynamodbSizeSetting,
+)
+from .new_auto_test_max_file_size_setting import NewAutoTestMaxFileSizeSetting
+from .new_auto_test_max_storage_size_setting import (
+    NewAutoTestMaxStorageSizeSetting,
+)
+from .new_auto_test_old_submission_age_setting import (
+    NewAutoTestOldSubmissionAgeSetting,
+)
+from .new_auto_test_test_max_command_time_setting import (
+    NewAutoTestTestMaxCommandTimeSetting,
+)
+from .new_auto_test_test_output_limit_setting import (
+    NewAutoTestTestOutputLimitSetting,
+)
 from .no_permissions import NoPermissions
 from .non_deleted_comment_reply import NonDeletedCommentReply
 from .non_finalized_lti1p1_provider import NonFinalizedLTI1p1Provider
@@ -400,6 +450,7 @@ from .patch1_p3_provider_lti_data import Patch1P3ProviderLTIData
 from .patch_all_notification_data import PatchAllNotificationData
 from .patch_assignment_data import PatchAssignmentData
 from .patch_auto_test_data import PatchAutoTestData
+from .patch_bulk_enroll_link_course_data import PatchBulkEnrollLinkCourseData
 from .patch_comment_reply_data import PatchCommentReplyData
 from .patch_course_data import PatchCourseData
 from .patch_grader_submission_data import PatchGraderSubmissionData
@@ -432,6 +483,10 @@ from .patch_user_data import PatchUserData
 from .pay_with_coupon_course_price_data import PayWithCouponCoursePriceData
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
 from .permission_exception import PermissionException
+from .personal_registration_link_info import PersonalRegistrationLinkInfo
+from .personal_registration_link_info_input_as_json import (
+    PersonalRegistrationLinkInfoInputAsJSON,
+)
 from .plagiarism_run import PlagiarismRun
 from .plagiarism_run_plagiarism_assignment_as_json import (
     PlagiarismRunPlagiarismAssignmentAsJSON,
@@ -440,9 +495,11 @@ from .plagiarism_run_plagiarism_course_as_json import (
     PlagiarismRunPlagiarismCourseAsJSON,
 )
 from .plagiarism_state import PlagiarismState
+from .post_bulk_enroll_link_course_data import PostBulkEnrollLinkCourseData
 from .post_oauth_token_data import PostOAuthTokenData
 from .present_preference import PresentPreference
 from .proxy import Proxy
+from .put_description_assignment_data import PutDescriptionAssignmentData
 from .put_enroll_link_course_data import PutEnrollLinkCourseData
 from .put_price_course_data import PutPriceCourseData
 from .put_price_tenant_data import PutPriceTenantData
@@ -452,6 +509,9 @@ from .quality_test_log import QualityTestLog
 from .quality_test_log_base import QualityTestLogBase
 from .register_enabled_setting import RegisterEnabledSetting
 from .register_user_data import RegisterUserData
+from .register_user_with_bulk_link_course_data import (
+    RegisterUserWithBulkLinkCourseData,
+)
 from .register_user_with_link_course_data import RegisterUserWithLinkCourseData
 from .release_info import ReleaseInfo
 from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
@@ -459,6 +519,9 @@ from .rename_group_group_data import RenameGroupGroupData
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
 from .reset_token_time_setting import ResetTokenTimeSetting
 from .result_data_get_auto_test_get import ResultDataGetAutoTestGet
+from .result_data_get_course_get_personalized_registration_link import (
+    ResultDataGetCourseGetPersonalizedRegistrationLink,
+)
 from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
 from .result_data_post_login_link_login import ResultDataPostLoginLinkLogin
 from .result_data_post_user_login import ResultDataPostUserLogin
@@ -466,6 +529,9 @@ from .result_data_post_user_register import ResultDataPostUserRegister
 from .role_as_json_with_perms import RoleAsJSONWithPerms
 from .root_file_trees_json import RootFileTreesJSON
 from .rubric_description_type import RubricDescriptionType
+from .rubric_enabled_for_teacher_on_submissions_page_setting import (
+    RubricEnabledForTeacherOnSubmissionsPageSetting,
+)
 from .rubric_item import RubricItem
 from .rubric_item_input_as_json import RubricItemInputAsJSON
 from .rubric_lock_reason import RubricLockReason
@@ -492,6 +558,9 @@ from .setup_oauth_result import SetupOAuthResult
 from .site_email_setting import SiteEmailSetting
 from .site_setting_input import SiteSettingInput
 from .snippet import Snippet
+from .sso_username_decollision_enabled_setting import (
+    SsoUsernameDecollisionEnabledSetting,
+)
 from .start_payment_course_price_close_tab_data import (
     StartPaymentCoursePriceCloseTabData,
 )
@@ -526,6 +595,7 @@ from .upgraded_lti_provider_exception import UpgradedLTIProviderException
 from .upload_submission_assignment_data import UploadSubmissionAssignmentData
 from .user import User
 from .user_course import UserCourse
+from .user_info_with_role import UserInfoWithRole
 from .user_input import UserInput
 from .user_without_group import UserWithoutGroup
 from .weak_password_exception import WeakPasswordException
