@@ -37,15 +37,27 @@ class AllSiteSettings(FrontendSiteSettings):
     auto_test_max_result_not_started: "datetime.timedelta"
     #: The maximum size of metadata stored on a unit test step.
     auto_test_max_unit_test_metadata_length: "int"
+    #: The maximum size of an AutoTest 2.0 configuration in the database.
+    new_auto_test_max_dynamodb_size: "int"
+    #: The maximum compound size of all the files uploaded as part of an
+    #: AutoTest 2.0 configuration.
+    new_auto_test_max_storage_size: "int"
+    #: The maximum size of a single file part of an AutoTest 2.0 configuration.
+    new_auto_test_max_file_size: "int"
+    #: The max output a command from a build step is allowed to output before
+    #: output is truncated.
+    new_auto_test_build_output_limit: "int"
+    #: The max output a command from a test step is allowed to output before
+    #: output is truncated.
+    new_auto_test_test_output_limit: "int"
+    #: The ID of the initial base image for the code execution virtual machines
+    #: which is shared between all users.
+    new_auto_test_initial_build_id: "str"
     #: The minimum strength passwords by users should have. The higher this
     #: value the stronger the password should be. When increasing the strength
     #: all users with too weak passwords will be shown a warning on the next
     #: login.
     min_password_score: "int"
-    #: The amount of time a reset token is valid. You should not increase this
-    #: value too much as users might be not be too careful with these tokens.
-    #: Increasing this value will allow **all** existing tokens to live longer.
-    reset_token_time: "datetime.timedelta"
     #: The amount of time the link send in notification emails to change the
     #: notification preferences works to actually change the notifications.
     setting_token_time: "datetime.timedelta"
@@ -83,6 +95,9 @@ class AllSiteSettings(FrontendSiteSettings):
     #: The time a user has to download a file from the mirror storage, after
     #: this time the file will be deleted.
     max_mirror_file_age: "datetime.timedelta"
+    #: Whether username decollision - adding a number after the username if it
+    #: already exists - should be enabled for SSO tenants.
+    sso_username_decollision_enabled: "bool"
     #: The maximum number of user settings stored per user.
     max_user_setting_amount: "int"
     #: Should a registration email be sent to new users upon registration.
@@ -152,6 +167,55 @@ class AllSiteSettings(FrontendSiteSettings):
                         " step."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_MAX_DYNAMODB_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum size of an AutoTest 2.0 configuration in"
+                        " the database."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_MAX_STORAGE_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum compound size of all the files uploaded"
+                        " as part of an AutoTest 2.0 configuration."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_MAX_FILE_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum size of a single file part of an AutoTest"
+                        " 2.0 configuration."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The max output a command from a build step is allowed"
+                        " to output before output is truncated."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_TEST_OUTPUT_LIMIT",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The max output a command from a test step is allowed"
+                        " to output before output is truncated."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_INITIAL_BUILD_ID",
+                    rqa.SimpleValue.str,
+                    doc=(
+                        "The ID of the initial base image for the code"
+                        " execution virtual machines which is shared between"
+                        " all users."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "MIN_PASSWORD_SCORE",
                     rqa.SimpleValue.int,
@@ -163,17 +227,6 @@ class AllSiteSettings(FrontendSiteSettings):
                         " the next login."
                     ),
                 ),
-                rqa.RequiredArgument(
-                    "RESET_TOKEN_TIME",
-                    rqa.RichValue.TimeDelta,
-                    doc=(
-                        "The amount of time a reset token is valid. You should"
-                        " not increase this value too much as users might be"
-                        " not be too careful with these tokens. Increasing"
-                        " this value will allow **all** existing tokens to"
-                        " live longer."
-                    ),
-                ),
                 rqa.RequiredArgument(
                     "SETTING_TOKEN_TIME",
                     rqa.RichValue.TimeDelta,
@@ -271,6 +324,15 @@ class AllSiteSettings(FrontendSiteSettings):
                         " deleted."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "SSO_USERNAME_DECOLLISION_ENABLED",
+                    rqa.SimpleValue.bool,
+                    doc=(
+                        "Whether username decollision - adding a number after"
+                        " the username if it already exists - should be"
+                        " enabled for SSO tenants."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "MAX_USER_SETTING_AMOUNT",
                     rqa.SimpleValue.int,
@@ -318,8 +380,25 @@ class AllSiteSettings(FrontendSiteSettings):
             "AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH": to_dict(
                 self.auto_test_max_unit_test_metadata_length
             ),
+            "NEW_AUTO_TEST_MAX_DYNAMODB_SIZE": to_dict(
+                self.new_auto_test_max_dynamodb_size
+            ),
+            "NEW_AUTO_TEST_MAX_STORAGE_SIZE": to_dict(
+                self.new_auto_test_max_storage_size
+            ),
+            "NEW_AUTO_TEST_MAX_FILE_SIZE": to_dict(
+                self.new_auto_test_max_file_size
+            ),
+            "NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT": to_dict(
+                self.new_auto_test_build_output_limit
+            ),
+            "NEW_AUTO_TEST_TEST_OUTPUT_LIMIT": to_dict(
+                self.new_auto_test_test_output_limit
+            ),
+            "NEW_AUTO_TEST_INITIAL_BUILD_ID": to_dict(
+                self.new_auto_test_initial_build_id
+            ),
             "MIN_PASSWORD_SCORE": to_dict(self.min_password_score),
-            "RESET_TOKEN_TIME": to_dict(self.reset_token_time),
             "SETTING_TOKEN_TIME": to_dict(self.setting_token_time),
             "MAX_NUMBER_OF_FILES": to_dict(self.max_number_of_files),
             "MAX_LARGE_UPLOAD_SIZE": to_dict(self.max_large_upload_size),
@@ -332,6 +411,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "MAX_DOCUMENT_UPDATE_SIZE": to_dict(self.max_document_update_size),
             "JWT_ACCESS_TOKEN_EXPIRES": to_dict(self.jwt_access_token_expires),
             "MAX_MIRROR_FILE_AGE": to_dict(self.max_mirror_file_age),
+            "SSO_USERNAME_DECOLLISION_ENABLED": to_dict(
+                self.sso_username_decollision_enabled
+            ),
             "MAX_USER_SETTING_AMOUNT": to_dict(self.max_user_setting_amount),
             "SEND_REGISTRATION_EMAIL": to_dict(self.send_registration_email),
             "AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT": to_dict(
@@ -361,8 +443,15 @@ class AllSiteSettings(FrontendSiteSettings):
             "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
                 self.auto_test_code_quality_message
             ),
+            "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME": to_dict(
+                self.new_auto_test_build_max_command_time
+            ),
+            "NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME": to_dict(
+                self.new_auto_test_test_max_command_time
+            ),
             "EXAM_LOGIN_MAX_LENGTH": to_dict(self.exam_login_max_length),
             "LOGIN_TOKEN_BEFORE_TIME": to_dict(self.login_token_before_time),
+            "RESET_TOKEN_TIME": to_dict(self.reset_token_time),
             "SITE_EMAIL": to_dict(self.site_email),
             "MAX_LINES": to_dict(self.max_lines),
             "NOTIFICATION_POLL_TIME": to_dict(self.notification_poll_time),
@@ -381,6 +470,9 @@ class AllSiteSettings(FrontendSiteSettings):
                 self.blackboard_zip_upload_enabled
             ),
             "RUBRICS_ENABLED": to_dict(self.rubrics_enabled),
+            "RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE": to_dict(
+                self.rubric_enabled_for_teacher_on_submissions_page
+            ),
             "AUTOMATIC_LTI_ROLE_ENABLED": to_dict(
                 self.automatic_lti_role_enabled
             ),
@@ -399,6 +491,7 @@ class AllSiteSettings(FrontendSiteSettings):
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
             "EDITOR_ENABLED": to_dict(self.editor_enabled),
+            "NEW_AUTO_TEST_ENABLED": to_dict(self.new_auto_test_enabled),
             "SERVER_TIME_CORRECTION_ENABLED": to_dict(
                 self.server_time_correction_enabled
             ),
@@ -450,6 +543,29 @@ class AllSiteSettings(FrontendSiteSettings):
             "ASSIGNMENT_MAX_POINTS_ENABLED": to_dict(
                 self.assignment_max_points_enabled
             ),
+            "COURSE_GRADEBOOK_ENABLED": to_dict(self.course_gradebook_enabled),
+            "ASSIGNMENT_DESCRIPTION_ENABLED": to_dict(
+                self.assignment_description_enabled
+            ),
+            "COURSE_GRADEBOOK_RENDER_WARNING_SIZE": to_dict(
+                self.course_gradebook_render_warning_size
+            ),
+            "COURSE_BULK_REGISTER_ENABLED": to_dict(
+                self.course_bulk_register_enabled
+            ),
+            "CSV_LARGE_FILE_LIMIT": to_dict(self.csv_large_file_limit),
+            "CSV_TOO_MANY_ERRORS_LIMIT": to_dict(
+                self.csv_too_many_errors_limit
+            ),
+            "NEW_AUTO_TEST_COPYING_ENABLED": to_dict(
+                self.new_auto_test_copying_enabled
+            ),
+            "NEW_AUTO_TEST_OLD_SUBMISSION_AGE": to_dict(
+                self.new_auto_test_old_submission_age
+            ),
+            "CANVAS_COURSE_ID_COPYING_ENABLED": to_dict(
+                self.canvas_course_id_copying_enabled
+            ),
         }
         return res
 
@@ -466,8 +582,13 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_max_concurrent_batch_runs=parsed.AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS,
             auto_test_max_result_not_started=parsed.AUTO_TEST_MAX_RESULT_NOT_STARTED,
             auto_test_max_unit_test_metadata_length=parsed.AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH,
+            new_auto_test_max_dynamodb_size=parsed.NEW_AUTO_TEST_MAX_DYNAMODB_SIZE,
+            new_auto_test_max_storage_size=parsed.NEW_AUTO_TEST_MAX_STORAGE_SIZE,
+            new_auto_test_max_file_size=parsed.NEW_AUTO_TEST_MAX_FILE_SIZE,
+            new_auto_test_build_output_limit=parsed.NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT,
+            new_auto_test_test_output_limit=parsed.NEW_AUTO_TEST_TEST_OUTPUT_LIMIT,
+            new_auto_test_initial_build_id=parsed.NEW_AUTO_TEST_INITIAL_BUILD_ID,
             min_password_score=parsed.MIN_PASSWORD_SCORE,
-            reset_token_time=parsed.RESET_TOKEN_TIME,
             setting_token_time=parsed.SETTING_TOKEN_TIME,
             max_number_of_files=parsed.MAX_NUMBER_OF_FILES,
             max_large_upload_size=parsed.MAX_LARGE_UPLOAD_SIZE,
@@ -478,6 +599,7 @@ class AllSiteSettings(FrontendSiteSettings):
             max_document_update_size=parsed.MAX_DOCUMENT_UPDATE_SIZE,
             jwt_access_token_expires=parsed.JWT_ACCESS_TOKEN_EXPIRES,
             max_mirror_file_age=parsed.MAX_MIRROR_FILE_AGE,
+            sso_username_decollision_enabled=parsed.SSO_USERNAME_DECOLLISION_ENABLED,
             max_user_setting_amount=parsed.MAX_USER_SETTING_AMOUNT,
             send_registration_email=parsed.SEND_REGISTRATION_EMAIL,
             automatic_lti_1p3_assignment_import=parsed.AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT,
@@ -489,8 +611,11 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_checkpoint_message=parsed.AUTO_TEST_CHECKPOINT_MESSAGE,
             auto_test_unit_test_message=parsed.AUTO_TEST_UNIT_TEST_MESSAGE,
             auto_test_code_quality_message=parsed.AUTO_TEST_CODE_QUALITY_MESSAGE,
+            new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
+            new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
             exam_login_max_length=parsed.EXAM_LOGIN_MAX_LENGTH,
             login_token_before_time=parsed.LOGIN_TOKEN_BEFORE_TIME,
+            reset_token_time=parsed.RESET_TOKEN_TIME,
             site_email=parsed.SITE_EMAIL,
             max_lines=parsed.MAX_LINES,
             notification_poll_time=parsed.NOTIFICATION_POLL_TIME,
@@ -501,6 +626,7 @@ class AllSiteSettings(FrontendSiteSettings):
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
+            rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
             automatic_lti_role_enabled=parsed.AUTOMATIC_LTI_ROLE_ENABLED,
             lti_enabled=parsed.LTI_ENABLED,
             linters_enabled=parsed.LINTERS_ENABLED,
@@ -515,6 +641,7 @@ class AllSiteSettings(FrontendSiteSettings):
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
             editor_enabled=parsed.EDITOR_ENABLED,
+            new_auto_test_enabled=parsed.NEW_AUTO_TEST_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
             grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
@@ -536,6 +663,15 @@ class AllSiteSettings(FrontendSiteSettings):
             assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
             lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
             assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
+            course_gradebook_enabled=parsed.COURSE_GRADEBOOK_ENABLED,
+            assignment_description_enabled=parsed.ASSIGNMENT_DESCRIPTION_ENABLED,
+            course_gradebook_render_warning_size=parsed.COURSE_GRADEBOOK_RENDER_WARNING_SIZE,
+            course_bulk_register_enabled=parsed.COURSE_BULK_REGISTER_ENABLED,
+            csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
+            csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
+            new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
+            canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
         res.raw_data = d
         return res
