@@ -33,8 +33,11 @@ class Assignment:
     id: "int"
     #: Current state of the assignment.
     state: "t.Literal['done', 'grading', 'hidden', 'submitting']"
-    #: Description of the assignment.
+    #: Description of the assignment. Deprecated, use available routes to
+    #: upload and retrieve a description file instead.
     description: "t.Optional[str]"
+    #: Whether the assignment has liked description file.
+    has_description: "bool"
     #: When this assignment was created.
     created_at: "datetime.datetime"
     #: The deadline of the assignment. It is possible the assignment has no
@@ -143,7 +146,16 @@ class Assignment:
             rqa.RequiredArgument(
                 "description",
                 rqa.Nullable(rqa.SimpleValue.str),
-                doc="Description of the assignment.",
+                doc=(
+                    "Description of the assignment. Deprecated, use available"
+                    " routes to upload and retrieve a description file"
+                    " instead."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "has_description",
+                rqa.SimpleValue.bool,
+                doc="Whether the assignment has liked description file.",
             ),
             rqa.RequiredArgument(
                 "created_at",
@@ -394,6 +406,7 @@ class Assignment:
             "id": to_dict(self.id),
             "state": to_dict(self.state),
             "description": to_dict(self.description),
+            "has_description": to_dict(self.has_description),
             "created_at": to_dict(self.created_at),
             "deadline": to_dict(self.deadline),
             "lock_date": to_dict(self.lock_date),
@@ -440,6 +453,7 @@ class Assignment:
             id=parsed.id,
             state=parsed.state,
             description=parsed.description,
+            has_description=parsed.has_description,
             created_at=parsed.created_at,
             deadline=parsed.deadline,
             lock_date=parsed.lock_date,
