@@ -253,6 +253,17 @@ class CoursePermMap:
     #: Users with this permissions can edit course sections, add users to them,
     #: and remove users from them.
     can_edit_course_sections: "bool"
+    #: Users with this permission can manage AutoTest 2.0 configurations.
+    can_manage_new_autotest: "bool"
+    #: Users with this permission can see the AutoTest 2.0 Test configuration.
+    can_view_new_autotest_test_steps: "bool"
+    #: Users with this permission can see the AutoTest 2.0 hidden step
+    #: configurations.
+    can_view_new_autotest_hidden_step_configuration: "bool"
+    #: Users with this permission can see the AutoTest 2.0 hidden step results.
+    can_view_new_autotest_hidden_step_results: "bool"
+    #: Users with this permission can see the AutoTest 2.0 hidden step output.
+    can_view_new_autotest_hidden_step_output: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -900,6 +911,46 @@ class CoursePermMap:
                     " users to them, and remove users from them."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_manage_new_autotest",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can manage AutoTest 2.0"
+                    " configurations."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_new_autotest_test_steps",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can see the AutoTest 2.0 Test"
+                    " configuration."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_new_autotest_hidden_step_configuration",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can see the AutoTest 2.0"
+                    " hidden step configurations."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_new_autotest_hidden_step_results",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can see the AutoTest 2.0"
+                    " hidden step results."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_new_autotest_hidden_step_output",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can see the AutoTest 2.0"
+                    " hidden step output."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -1043,6 +1094,19 @@ class CoursePermMap:
             ),
             "can_view_course_sections": to_dict(self.can_view_course_sections),
             "can_edit_course_sections": to_dict(self.can_edit_course_sections),
+            "can_manage_new_autotest": to_dict(self.can_manage_new_autotest),
+            "can_view_new_autotest_test_steps": to_dict(
+                self.can_view_new_autotest_test_steps
+            ),
+            "can_view_new_autotest_hidden_step_configuration": to_dict(
+                self.can_view_new_autotest_hidden_step_configuration
+            ),
+            "can_view_new_autotest_hidden_step_results": to_dict(
+                self.can_view_new_autotest_hidden_step_results
+            ),
+            "can_view_new_autotest_hidden_step_output": to_dict(
+                self.can_view_new_autotest_hidden_step_output
+            ),
         }
         return res
 
@@ -1129,6 +1193,11 @@ class CoursePermMap:
             can_view_others_in_section_comment_edits=parsed.can_view_others_in_section_comment_edits,
             can_view_course_sections=parsed.can_view_course_sections,
             can_edit_course_sections=parsed.can_edit_course_sections,
+            can_manage_new_autotest=parsed.can_manage_new_autotest,
+            can_view_new_autotest_test_steps=parsed.can_view_new_autotest_test_steps,
+            can_view_new_autotest_hidden_step_configuration=parsed.can_view_new_autotest_hidden_step_configuration,
+            can_view_new_autotest_hidden_step_results=parsed.can_view_new_autotest_hidden_step_results,
+            can_view_new_autotest_hidden_step_output=parsed.can_view_new_autotest_hidden_step_output,
         )
         res.raw_data = d
         return res
