@@ -90,3 +90,14 @@ class CoursePermission(str, Enum):
     )
     can_view_course_sections = "can_view_course_sections"
     can_edit_course_sections = "can_edit_course_sections"
+    can_manage_new_autotest = "can_manage_new_autotest"
+    can_view_new_autotest_test_steps = "can_view_new_autotest_test_steps"
+    can_view_new_autotest_hidden_step_configuration = (
+        "can_view_new_autotest_hidden_step_configuration"
+    )
+    can_view_new_autotest_hidden_step_results = (
+        "can_view_new_autotest_hidden_step_results"
+    )
+    can_view_new_autotest_hidden_step_output = (
+        "can_view_new_autotest_hidden_step_output"
+    )
