@@ -33,6 +33,10 @@ class FrontendSiteSettings:
     auto_test_unit_test_message: "str"
     #: Default message for Code Quality steps of an AutoTest.
     auto_test_code_quality_message: "str"
+    #: The maximum time a command may run in the build part of AutoTest 2.0.
+    new_auto_test_build_max_command_time: "datetime.timedelta"
+    #: The maximum time a command may run in the test part of AutoTest 2.0.
+    new_auto_test_test_max_command_time: "datetime.timedelta"
     #: The maximum time-delta an exam may take. Increasing this value also
     #: increases the maximum amount of time the login tokens send via email are
     #: valid. Therefore, you should make this too long.
@@ -40,6 +44,10 @@ class FrontendSiteSettings:
     #: This determines how long before the exam we will send the login emails
     #: to the students (only when enabled of course).
     login_token_before_time: "t.Sequence[datetime.timedelta]"
+    #: The amount of time a reset token is valid. You should not increase this
+    #: value too much as users might be not be too careful with these tokens.
+    #: Increasing this value will allow **all** existing tokens to live longer.
+    reset_token_time: "datetime.timedelta"
     #: The email shown to users as the email of CodeGrade.
     site_email: "str"
     #: The maximum amount of lines that we should in render in one go. If a
@@ -48,7 +56,7 @@ class FrontendSiteSettings:
     max_lines: "int"
     #: The amount of time to wait between two consecutive polls to see if a
     #: user has new notifications. Setting this value too low will cause
-    #: unnecessary stres on the server.
+    #: unnecessary stress on the server.
     notification_poll_time: "datetime.timedelta"
     #: What is the maximum amount of time after a release a message should be
     #: shown on the HomeGrid. **Note**: this is the amount of time after the
@@ -63,7 +71,7 @@ class FrontendSiteSettings:
     auto_test_max_global_setup_time: "datetime.timedelta"
     #: The maximum amount of time that the per student setup script in AutoTest
     #: may take. If it takes longer than this it will be killed and the result
-    #: of the student will be in the state "timed-out"
+    #: of the student will be in the state "timed-out".
     auto_test_max_per_student_setup_time: "datetime.timedelta"
     #: The default value for the grading scale of new assignments.
     assignment_default_grading_scale: "t.Literal['percentage', 'points']"
@@ -73,11 +81,15 @@ class FrontendSiteSettings:
     #: If enabled teachers can use rubrics on CodeGrade. Disabling this feature
     #: will not delete existing rubrics.
     rubrics_enabled: "bool"
-    #: Currently unused
+    #: If enabled teachers can view rubrics on the submissions list page. Here
+    #: they have the student view version of the rubric as apposed to the
+    #: editor view in the manage assignment page.
+    rubric_enabled_for_teacher_on_submissions_page: "bool"
+    #: Currently unused.
     automatic_lti_role_enabled: "bool"
     #: Should LTI be enabled.
     lti_enabled: "bool"
-    #: Should linters be enabled
+    #: Should linters be enabled.
     linters_enabled: "bool"
     #: Should rubrics be submitted incrementally, so if a user selects a item
     #: should this be automatically be submitted to the server, or should it
@@ -111,13 +123,16 @@ class FrontendSiteSettings:
     student_payment_enabled: "bool"
     #: Can students submit using the online editor.
     editor_enabled: "bool"
+    #: Can AutoTest configurations be created and run using the 2.0
+    #: infrastructure.
+    new_auto_test_enabled: "bool"
     #: Whether the time as detected locally on a user's computer is corrected
     #: by the difference with the time as reported by the backend server.
     server_time_correction_enabled: "bool"
     #: Whether the gathering of user behaviour events and subsequent metrics
     #: enabled.
     metric_gathering_enabled: "bool"
-    #: Whether teachers have access to the assignment manager -notifications
+    #: Whether teachers have access to the assignment manager - notifications
     #: panel, which gives control over when to send notifications to graders to
     #: finish their job, and also allows teachers to provide email(s) to notify
     #: when all graders are finished.
@@ -178,6 +193,33 @@ class FrontendSiteSettings:
     #: enabled. If disabled, teachers will not be able to award extra points
     #: for assignments.
     assignment_max_points_enabled: "bool"
+    #: Whether the gradebook on the course management page is enabled.
+    course_gradebook_enabled: "bool"
+    #: Wether the description on the assignment management page is enabled.
+    assignment_description_enabled: "bool"
+    #: The minimum size of a gradebook before we show a warning that there are
+    #: so many entries in the gradebook that it may slow down rendering or
+    #: crash the page.
+    course_gradebook_render_warning_size: "int"
+    #: Whether it is possible for teachers to create links for batches of users
+    #: that can be used to register in a course. Links to enroll can be created
+    #: even if this feature is disabled.
+    course_bulk_register_enabled: "bool"
+    #: The file size above which users will be shown a warning that parsing the
+    #: file might cause a slow down in their browser.
+    csv_large_file_limit: "int"
+    #: The amount of errors that occur above which we will ask the user to make
+    #: sure that the given file is actually a CSV.
+    csv_too_many_errors_limit: "int"
+    #: Whether AutoTest 2.0 configuration importing from other assignments is
+    #: enabled.
+    new_auto_test_copying_enabled: "bool"
+    #: The maximum age a submission can be before we do not retry subscribing
+    #: to its result if it cannot be found the first time.
+    new_auto_test_old_submission_age: "datetime.timedelta"
+    #: Should course id form Canvas be copied through LTI(1.3), and stored in
+    #: our database or not.
+    canvas_course_id_copying_enabled: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -226,6 +268,22 @@ class FrontendSiteSettings:
                 rqa.SimpleValue.str,
                 doc="Default message for Code Quality steps of an AutoTest.",
             ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum time a command may run in the build part of"
+                    " AutoTest 2.0."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum time a command may run in the test part of"
+                    " AutoTest 2.0."
+                ),
+            ),
             rqa.RequiredArgument(
                 "EXAM_LOGIN_MAX_LENGTH",
                 rqa.RichValue.TimeDelta,
@@ -245,6 +303,16 @@ class FrontendSiteSettings:
                     " course)."
                 ),
             ),
+            rqa.RequiredArgument(
+                "RESET_TOKEN_TIME",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The amount of time a reset token is valid. You should not"
+                    " increase this value too much as users might be not be"
+                    " too careful with these tokens. Increasing this value"
+                    " will allow **all** existing tokens to live longer."
+                ),
+            ),
             rqa.RequiredArgument(
                 "SITE_EMAIL",
                 rqa.SimpleValue.str,
@@ -265,7 +333,7 @@ class FrontendSiteSettings:
                 doc=(
                     "The amount of time to wait between two consecutive polls"
                     " to see if a user has new notifications. Setting this"
-                    " value too low will cause unnecessary stres on the"
+                    " value too low will cause unnecessary stress on the"
                     " server."
                 ),
             ),
@@ -304,7 +372,7 @@ class FrontendSiteSettings:
                     "The maximum amount of time that the per student setup"
                     " script in AutoTest may take. If it takes longer than"
                     " this it will be killed and the result of the student"
-                    ' will be in the state "timed-out"'
+                    ' will be in the state "timed-out".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -332,10 +400,20 @@ class FrontendSiteSettings:
                     " Disabling this feature will not delete existing rubrics."
                 ),
             ),
+            rqa.RequiredArgument(
+                "RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "If enabled teachers can view rubrics on the submissions"
+                    " list page. Here they have the student view version of"
+                    " the rubric as apposed to the editor view in the manage"
+                    " assignment page."
+                ),
+            ),
             rqa.RequiredArgument(
                 "AUTOMATIC_LTI_ROLE_ENABLED",
                 rqa.SimpleValue.bool,
-                doc="Currently unused",
+                doc="Currently unused.",
             ),
             rqa.RequiredArgument(
                 "LTI_ENABLED",
@@ -345,7 +423,7 @@ class FrontendSiteSettings:
             rqa.RequiredArgument(
                 "LINTERS_ENABLED",
                 rqa.SimpleValue.bool,
-                doc="Should linters be enabled",
+                doc="Should linters be enabled.",
             ),
             rqa.RequiredArgument(
                 "INCREMENTAL_RUBRIC_SUBMISSION_ENABLED",
@@ -425,6 +503,14 @@ class FrontendSiteSettings:
                 rqa.SimpleValue.bool,
                 doc="Can students submit using the online editor.",
             ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Can AutoTest configurations be created and run using the"
+                    " 2.0 infrastructure."
+                ),
+            ),
             rqa.RequiredArgument(
                 "SERVER_TIME_CORRECTION_ENABLED",
                 rqa.SimpleValue.bool,
@@ -446,8 +532,8 @@ class FrontendSiteSettings:
                 "GRADING_NOTIFICATIONS_ENABLED",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Whether teachers have access to the assignment manager"
-                    " -notifications panel, which gives control over when to"
+                    "Whether teachers have access to the assignment manager -"
+                    " notifications panel, which gives control over when to"
                     " send notifications to graders to finish their job, and"
                     " also allows teachers to provide email(s) to notify when"
                     " all graders are finished."
@@ -598,6 +684,84 @@ class FrontendSiteSettings:
                     " not be able to award extra points for assignments."
                 ),
             ),
+            rqa.RequiredArgument(
+                "COURSE_GRADEBOOK_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the gradebook on the course management page is"
+                    " enabled."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_DESCRIPTION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Wether the description on the assignment management page"
+                    " is enabled."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "COURSE_GRADEBOOK_RENDER_WARNING_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The minimum size of a gradebook before we show a warning"
+                    " that there are so many entries in the gradebook that it"
+                    " may slow down rendering or crash the page."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "COURSE_BULK_REGISTER_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether it is possible for teachers to create links for"
+                    " batches of users that can be used to register in a"
+                    " course. Links to enroll can be created even if this"
+                    " feature is disabled."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "CSV_LARGE_FILE_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The file size above which users will be shown a warning"
+                    " that parsing the file might cause a slow down in their"
+                    " browser."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "CSV_TOO_MANY_ERRORS_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The amount of errors that occur above which we will ask"
+                    " the user to make sure that the given file is actually a"
+                    " CSV."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether AutoTest 2.0 configuration importing from other"
+                    " assignments is enabled."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_OLD_SUBMISSION_AGE",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum age a submission can be before we do not"
+                    " retry subscribing to its result if it cannot be found"
+                    " the first time."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "CANVAS_COURSE_ID_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should course id form Canvas be copied through LTI(1.3),"
+                    " and stored in our database or not."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -627,8 +791,15 @@ class FrontendSiteSettings:
             "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
                 self.auto_test_code_quality_message
             ),
+            "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME": to_dict(
+                self.new_auto_test_build_max_command_time
+            ),
+            "NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME": to_dict(
+                self.new_auto_test_test_max_command_time
+            ),
             "EXAM_LOGIN_MAX_LENGTH": to_dict(self.exam_login_max_length),
             "LOGIN_TOKEN_BEFORE_TIME": to_dict(self.login_token_before_time),
+            "RESET_TOKEN_TIME": to_dict(self.reset_token_time),
             "SITE_EMAIL": to_dict(self.site_email),
             "MAX_LINES": to_dict(self.max_lines),
             "NOTIFICATION_POLL_TIME": to_dict(self.notification_poll_time),
@@ -647,6 +818,9 @@ class FrontendSiteSettings:
                 self.blackboard_zip_upload_enabled
             ),
             "RUBRICS_ENABLED": to_dict(self.rubrics_enabled),
+            "RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE": to_dict(
+                self.rubric_enabled_for_teacher_on_submissions_page
+            ),
             "AUTOMATIC_LTI_ROLE_ENABLED": to_dict(
                 self.automatic_lti_role_enabled
             ),
@@ -665,6 +839,7 @@ class FrontendSiteSettings:
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
             "EDITOR_ENABLED": to_dict(self.editor_enabled),
+            "NEW_AUTO_TEST_ENABLED": to_dict(self.new_auto_test_enabled),
             "SERVER_TIME_CORRECTION_ENABLED": to_dict(
                 self.server_time_correction_enabled
             ),
@@ -716,6 +891,29 @@ class FrontendSiteSettings:
             "ASSIGNMENT_MAX_POINTS_ENABLED": to_dict(
                 self.assignment_max_points_enabled
             ),
+            "COURSE_GRADEBOOK_ENABLED": to_dict(self.course_gradebook_enabled),
+            "ASSIGNMENT_DESCRIPTION_ENABLED": to_dict(
+                self.assignment_description_enabled
+            ),
+            "COURSE_GRADEBOOK_RENDER_WARNING_SIZE": to_dict(
+                self.course_gradebook_render_warning_size
+            ),
+            "COURSE_BULK_REGISTER_ENABLED": to_dict(
+                self.course_bulk_register_enabled
+            ),
+            "CSV_LARGE_FILE_LIMIT": to_dict(self.csv_large_file_limit),
+            "CSV_TOO_MANY_ERRORS_LIMIT": to_dict(
+                self.csv_too_many_errors_limit
+            ),
+            "NEW_AUTO_TEST_COPYING_ENABLED": to_dict(
+                self.new_auto_test_copying_enabled
+            ),
+            "NEW_AUTO_TEST_OLD_SUBMISSION_AGE": to_dict(
+                self.new_auto_test_old_submission_age
+            ),
+            "CANVAS_COURSE_ID_COPYING_ENABLED": to_dict(
+                self.canvas_course_id_copying_enabled
+            ),
         }
         return res
 
@@ -734,8 +932,11 @@ class FrontendSiteSettings:
             auto_test_checkpoint_message=parsed.AUTO_TEST_CHECKPOINT_MESSAGE,
             auto_test_unit_test_message=parsed.AUTO_TEST_UNIT_TEST_MESSAGE,
             auto_test_code_quality_message=parsed.AUTO_TEST_CODE_QUALITY_MESSAGE,
+            new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
+            new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
             exam_login_max_length=parsed.EXAM_LOGIN_MAX_LENGTH,
             login_token_before_time=parsed.LOGIN_TOKEN_BEFORE_TIME,
+            reset_token_time=parsed.RESET_TOKEN_TIME,
             site_email=parsed.SITE_EMAIL,
             max_lines=parsed.MAX_LINES,
             notification_poll_time=parsed.NOTIFICATION_POLL_TIME,
@@ -746,6 +947,7 @@ class FrontendSiteSettings:
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
+            rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
             automatic_lti_role_enabled=parsed.AUTOMATIC_LTI_ROLE_ENABLED,
             lti_enabled=parsed.LTI_ENABLED,
             linters_enabled=parsed.LINTERS_ENABLED,
@@ -760,6 +962,7 @@ class FrontendSiteSettings:
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
             editor_enabled=parsed.EDITOR_ENABLED,
+            new_auto_test_enabled=parsed.NEW_AUTO_TEST_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
             grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
@@ -781,6 +984,15 @@ class FrontendSiteSettings:
             assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
             lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
             assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
+            course_gradebook_enabled=parsed.COURSE_GRADEBOOK_ENABLED,
+            assignment_description_enabled=parsed.ASSIGNMENT_DESCRIPTION_ENABLED,
+            course_gradebook_render_warning_size=parsed.COURSE_GRADEBOOK_RENDER_WARNING_SIZE,
+            course_bulk_register_enabled=parsed.COURSE_BULK_REGISTER_ENABLED,
+            csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
+            csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
+            new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
+            canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
         res.raw_data = d
         return res
