@@ -55,6 +55,26 @@ class PartialAllSiteSettings:
     auto_test_max_result_not_started: Maybe["datetime.timedelta"] = Nothing
     #: The maximum size of metadata stored on a unit test step.
     auto_test_max_unit_test_metadata_length: Maybe["int"] = Nothing
+    #: The maximum size of an AutoTest 2.0 configuration in the database.
+    new_auto_test_max_dynamodb_size: Maybe["int"] = Nothing
+    #: The maximum compound size of all the files uploaded as part of an
+    #: AutoTest 2.0 configuration.
+    new_auto_test_max_storage_size: Maybe["int"] = Nothing
+    #: The maximum size of a single file part of an AutoTest 2.0 configuration.
+    new_auto_test_max_file_size: Maybe["int"] = Nothing
+    #: The max output a command from a build step is allowed to output before
+    #: output is truncated.
+    new_auto_test_build_output_limit: Maybe["int"] = Nothing
+    #: The max output a command from a test step is allowed to output before
+    #: output is truncated.
+    new_auto_test_test_output_limit: Maybe["int"] = Nothing
+    #: The ID of the initial base image for the code execution virtual machines
+    #: which is shared between all users.
+    new_auto_test_initial_build_id: Maybe["str"] = Nothing
+    #: The maximum time a command may run in the build part of AutoTest 2.0.
+    new_auto_test_build_max_command_time: Maybe["datetime.timedelta"] = Nothing
+    #: The maximum time a command may run in the test part of AutoTest 2.0.
+    new_auto_test_test_max_command_time: Maybe["datetime.timedelta"] = Nothing
     #: The maximum time-delta an exam may take. Increasing this value also
     #: increases the maximum amount of time the login tokens send via email are
     #: valid. Therefore, you should make this too long.
@@ -113,7 +133,7 @@ class PartialAllSiteSettings:
     max_lines: Maybe["int"] = Nothing
     #: The amount of time to wait between two consecutive polls to see if a
     #: user has new notifications. Setting this value too low will cause
-    #: unnecessary stres on the server.
+    #: unnecessary stress on the server.
     notification_poll_time: Maybe["datetime.timedelta"] = Nothing
     #: What is the maximum amount of time after a release a message should be
     #: shown on the HomeGrid. **Note**: this is the amount of time after the
@@ -131,7 +151,7 @@ class PartialAllSiteSettings:
     auto_test_max_global_setup_time: Maybe["datetime.timedelta"] = Nothing
     #: The maximum amount of time that the per student setup script in AutoTest
     #: may take. If it takes longer than this it will be killed and the result
-    #: of the student will be in the state "timed-out"
+    #: of the student will be in the state "timed-out".
     auto_test_max_per_student_setup_time: Maybe["datetime.timedelta"] = Nothing
     #: The default value for the grading scale of new assignments.
     assignment_default_grading_scale: Maybe[
@@ -143,11 +163,15 @@ class PartialAllSiteSettings:
     #: If enabled teachers can use rubrics on CodeGrade. Disabling this feature
     #: will not delete existing rubrics.
     rubrics_enabled: Maybe["bool"] = Nothing
-    #: Currently unused
+    #: If enabled teachers can view rubrics on the submissions list page. Here
+    #: they have the student view version of the rubric as apposed to the
+    #: editor view in the manage assignment page.
+    rubric_enabled_for_teacher_on_submissions_page: Maybe["bool"] = Nothing
+    #: Currently unused.
     automatic_lti_role_enabled: Maybe["bool"] = Nothing
     #: Should LTI be enabled.
     lti_enabled: Maybe["bool"] = Nothing
-    #: Should linters be enabled
+    #: Should linters be enabled.
     linters_enabled: Maybe["bool"] = Nothing
     #: Should rubrics be submitted incrementally, so if a user selects a item
     #: should this be automatically be submitted to the server, or should it
@@ -181,17 +205,23 @@ class PartialAllSiteSettings:
     student_payment_enabled: Maybe["bool"] = Nothing
     #: Can students submit using the online editor.
     editor_enabled: Maybe["bool"] = Nothing
+    #: Can AutoTest configurations be created and run using the 2.0
+    #: infrastructure.
+    new_auto_test_enabled: Maybe["bool"] = Nothing
     #: Whether the time as detected locally on a user's computer is corrected
     #: by the difference with the time as reported by the backend server.
     server_time_correction_enabled: Maybe["bool"] = Nothing
     #: Whether the gathering of user behaviour events and subsequent metrics
     #: enabled.
     metric_gathering_enabled: Maybe["bool"] = Nothing
-    #: Whether teachers have access to the assignment manager -notifications
+    #: Whether teachers have access to the assignment manager - notifications
     #: panel, which gives control over when to send notifications to graders to
     #: finish their job, and also allows teachers to provide email(s) to notify
     #: when all graders are finished.
     grading_notifications_enabled: Maybe["bool"] = Nothing
+    #: Whether username decollision - adding a number after the username if it
+    #: already exists - should be enabled for SSO tenants.
+    sso_username_decollision_enabled: Maybe["bool"] = Nothing
     #: Feedback threads will start collapsed from this depth of the tree.
     feedback_threads_initially_collapsed: Maybe["int"] = Nothing
     #: The maximum number of user settings stored per user.
@@ -256,6 +286,33 @@ class PartialAllSiteSettings:
     #: enabled. If disabled, teachers will not be able to award extra points
     #: for assignments.
     assignment_max_points_enabled: Maybe["bool"] = Nothing
+    #: Whether the gradebook on the course management page is enabled.
+    course_gradebook_enabled: Maybe["bool"] = Nothing
+    #: Wether the description on the assignment management page is enabled.
+    assignment_description_enabled: Maybe["bool"] = Nothing
+    #: The minimum size of a gradebook before we show a warning that there are
+    #: so many entries in the gradebook that it may slow down rendering or
+    #: crash the page.
+    course_gradebook_render_warning_size: Maybe["int"] = Nothing
+    #: Whether it is possible for teachers to create links for batches of users
+    #: that can be used to register in a course. Links to enroll can be created
+    #: even if this feature is disabled.
+    course_bulk_register_enabled: Maybe["bool"] = Nothing
+    #: The file size above which users will be shown a warning that parsing the
+    #: file might cause a slow down in their browser.
+    csv_large_file_limit: Maybe["int"] = Nothing
+    #: The amount of errors that occur above which we will ask the user to make
+    #: sure that the given file is actually a CSV.
+    csv_too_many_errors_limit: Maybe["int"] = Nothing
+    #: Whether AutoTest 2.0 configuration importing from other assignments is
+    #: enabled.
+    new_auto_test_copying_enabled: Maybe["bool"] = Nothing
+    #: The maximum age a submission can be before we do not retry subscribing
+    #: to its result if it cannot be found the first time.
+    new_auto_test_old_submission_age: Maybe["datetime.timedelta"] = Nothing
+    #: Should course id form Canvas be copied through LTI(1.3), and stored in
+    #: our database or not.
+    canvas_course_id_copying_enabled: Maybe["bool"] = Nothing
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -355,6 +412,70 @@ class PartialAllSiteSettings:
                 rqa.SimpleValue.int,
                 doc="The maximum size of metadata stored on a unit test step.",
             ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_MAX_DYNAMODB_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The maximum size of an AutoTest 2.0 configuration in the"
+                    " database."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_MAX_STORAGE_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The maximum compound size of all the files uploaded as"
+                    " part of an AutoTest 2.0 configuration."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_MAX_FILE_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The maximum size of a single file part of an AutoTest 2.0"
+                    " configuration."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The max output a command from a build step is allowed to"
+                    " output before output is truncated."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_TEST_OUTPUT_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The max output a command from a test step is allowed to"
+                    " output before output is truncated."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_INITIAL_BUILD_ID",
+                rqa.SimpleValue.str,
+                doc=(
+                    "The ID of the initial base image for the code execution"
+                    " virtual machines which is shared between all users."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum time a command may run in the build part of"
+                    " AutoTest 2.0."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum time a command may run in the test part of"
+                    " AutoTest 2.0."
+                ),
+            ),
             rqa.OptionalArgument(
                 "EXAM_LOGIN_MAX_LENGTH",
                 rqa.RichValue.TimeDelta,
@@ -502,7 +623,7 @@ class PartialAllSiteSettings:
                 doc=(
                     "The amount of time to wait between two consecutive polls"
                     " to see if a user has new notifications. Setting this"
-                    " value too low will cause unnecessary stres on the"
+                    " value too low will cause unnecessary stress on the"
                     " server."
                 ),
             ),
@@ -549,7 +670,7 @@ class PartialAllSiteSettings:
                     "The maximum amount of time that the per student setup"
                     " script in AutoTest may take. If it takes longer than"
                     " this it will be killed and the result of the student"
-                    ' will be in the state "timed-out"'
+                    ' will be in the state "timed-out".'
                 ),
             ),
             rqa.OptionalArgument(
@@ -577,10 +698,20 @@ class PartialAllSiteSettings:
                     " Disabling this feature will not delete existing rubrics."
                 ),
             ),
+            rqa.OptionalArgument(
+                "RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "If enabled teachers can view rubrics on the submissions"
+                    " list page. Here they have the student view version of"
+                    " the rubric as apposed to the editor view in the manage"
+                    " assignment page."
+                ),
+            ),
             rqa.OptionalArgument(
                 "AUTOMATIC_LTI_ROLE_ENABLED",
                 rqa.SimpleValue.bool,
-                doc="Currently unused",
+                doc="Currently unused.",
             ),
             rqa.OptionalArgument(
                 "LTI_ENABLED",
@@ -590,7 +721,7 @@ class PartialAllSiteSettings:
             rqa.OptionalArgument(
                 "LINTERS_ENABLED",
                 rqa.SimpleValue.bool,
-                doc="Should linters be enabled",
+                doc="Should linters be enabled.",
             ),
             rqa.OptionalArgument(
                 "INCREMENTAL_RUBRIC_SUBMISSION_ENABLED",
@@ -670,6 +801,14 @@ class PartialAllSiteSettings:
                 rqa.SimpleValue.bool,
                 doc="Can students submit using the online editor.",
             ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Can AutoTest configurations be created and run using the"
+                    " 2.0 infrastructure."
+                ),
+            ),
             rqa.OptionalArgument(
                 "SERVER_TIME_CORRECTION_ENABLED",
                 rqa.SimpleValue.bool,
@@ -691,13 +830,22 @@ class PartialAllSiteSettings:
                 "GRADING_NOTIFICATIONS_ENABLED",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Whether teachers have access to the assignment manager"
-                    " -notifications panel, which gives control over when to"
+                    "Whether teachers have access to the assignment manager -"
+                    " notifications panel, which gives control over when to"
                     " send notifications to graders to finish their job, and"
                     " also allows teachers to provide email(s) to notify when"
                     " all graders are finished."
                 ),
             ),
+            rqa.OptionalArgument(
+                "SSO_USERNAME_DECOLLISION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether username decollision - adding a number after the"
+                    " username if it already exists - should be enabled for"
+                    " SSO tenants."
+                ),
+            ),
             rqa.OptionalArgument(
                 "FEEDBACK_THREADS_INITIALLY_COLLAPSED",
                 rqa.SimpleValue.int,
@@ -866,6 +1014,84 @@ class PartialAllSiteSettings:
                     " not be able to award extra points for assignments."
                 ),
             ),
+            rqa.OptionalArgument(
+                "COURSE_GRADEBOOK_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the gradebook on the course management page is"
+                    " enabled."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "ASSIGNMENT_DESCRIPTION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Wether the description on the assignment management page"
+                    " is enabled."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "COURSE_GRADEBOOK_RENDER_WARNING_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The minimum size of a gradebook before we show a warning"
+                    " that there are so many entries in the gradebook that it"
+                    " may slow down rendering or crash the page."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "COURSE_BULK_REGISTER_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether it is possible for teachers to create links for"
+                    " batches of users that can be used to register in a"
+                    " course. Links to enroll can be created even if this"
+                    " feature is disabled."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "CSV_LARGE_FILE_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The file size above which users will be shown a warning"
+                    " that parsing the file might cause a slow down in their"
+                    " browser."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "CSV_TOO_MANY_ERRORS_LIMIT",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The amount of errors that occur above which we will ask"
+                    " the user to make sure that the given file is actually a"
+                    " CSV."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether AutoTest 2.0 configuration importing from other"
+                    " assignments is enabled."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_OLD_SUBMISSION_AGE",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum age a submission can be before we do not"
+                    " retry subscribing to its result if it cannot be found"
+                    " the first time."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "CANVAS_COURSE_ID_COPYING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should course id form Canvas be copied through LTI(1.3),"
+                    " and stored in our database or not."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -913,6 +1139,30 @@ class PartialAllSiteSettings:
         self.auto_test_max_unit_test_metadata_length = maybe_from_nullable(
             self.auto_test_max_unit_test_metadata_length
         )
+        self.new_auto_test_max_dynamodb_size = maybe_from_nullable(
+            self.new_auto_test_max_dynamodb_size
+        )
+        self.new_auto_test_max_storage_size = maybe_from_nullable(
+            self.new_auto_test_max_storage_size
+        )
+        self.new_auto_test_max_file_size = maybe_from_nullable(
+            self.new_auto_test_max_file_size
+        )
+        self.new_auto_test_build_output_limit = maybe_from_nullable(
+            self.new_auto_test_build_output_limit
+        )
+        self.new_auto_test_test_output_limit = maybe_from_nullable(
+            self.new_auto_test_test_output_limit
+        )
+        self.new_auto_test_initial_build_id = maybe_from_nullable(
+            self.new_auto_test_initial_build_id
+        )
+        self.new_auto_test_build_max_command_time = maybe_from_nullable(
+            self.new_auto_test_build_max_command_time
+        )
+        self.new_auto_test_test_max_command_time = maybe_from_nullable(
+            self.new_auto_test_test_max_command_time
+        )
         self.exam_login_max_length = maybe_from_nullable(
             self.exam_login_max_length
         )
@@ -971,6 +1221,11 @@ class PartialAllSiteSettings:
             self.blackboard_zip_upload_enabled
         )
         self.rubrics_enabled = maybe_from_nullable(self.rubrics_enabled)
+        self.rubric_enabled_for_teacher_on_submissions_page = (
+            maybe_from_nullable(
+                self.rubric_enabled_for_teacher_on_submissions_page
+            )
+        )
         self.automatic_lti_role_enabled = maybe_from_nullable(
             self.automatic_lti_role_enabled
         )
@@ -1001,6 +1256,9 @@ class PartialAllSiteSettings:
             self.student_payment_enabled
         )
         self.editor_enabled = maybe_from_nullable(self.editor_enabled)
+        self.new_auto_test_enabled = maybe_from_nullable(
+            self.new_auto_test_enabled
+        )
         self.server_time_correction_enabled = maybe_from_nullable(
             self.server_time_correction_enabled
         )
@@ -1010,6 +1268,9 @@ class PartialAllSiteSettings:
         self.grading_notifications_enabled = maybe_from_nullable(
             self.grading_notifications_enabled
         )
+        self.sso_username_decollision_enabled = maybe_from_nullable(
+            self.sso_username_decollision_enabled
+        )
         self.feedback_threads_initially_collapsed = maybe_from_nullable(
             self.feedback_threads_initially_collapsed
         )
@@ -1073,6 +1334,33 @@ class PartialAllSiteSettings:
         self.assignment_max_points_enabled = maybe_from_nullable(
             self.assignment_max_points_enabled
         )
+        self.course_gradebook_enabled = maybe_from_nullable(
+            self.course_gradebook_enabled
+        )
+        self.assignment_description_enabled = maybe_from_nullable(
+            self.assignment_description_enabled
+        )
+        self.course_gradebook_render_warning_size = maybe_from_nullable(
+            self.course_gradebook_render_warning_size
+        )
+        self.course_bulk_register_enabled = maybe_from_nullable(
+            self.course_bulk_register_enabled
+        )
+        self.csv_large_file_limit = maybe_from_nullable(
+            self.csv_large_file_limit
+        )
+        self.csv_too_many_errors_limit = maybe_from_nullable(
+            self.csv_too_many_errors_limit
+        )
+        self.new_auto_test_copying_enabled = maybe_from_nullable(
+            self.new_auto_test_copying_enabled
+        )
+        self.new_auto_test_old_submission_age = maybe_from_nullable(
+            self.new_auto_test_old_submission_age
+        )
+        self.canvas_course_id_copying_enabled = maybe_from_nullable(
+            self.canvas_course_id_copying_enabled
+        )
 
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {}
@@ -1132,6 +1420,38 @@ class PartialAllSiteSettings:
             res["AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH"] = to_dict(
                 self.auto_test_max_unit_test_metadata_length.value
             )
+        if self.new_auto_test_max_dynamodb_size.is_just:
+            res["NEW_AUTO_TEST_MAX_DYNAMODB_SIZE"] = to_dict(
+                self.new_auto_test_max_dynamodb_size.value
+            )
+        if self.new_auto_test_max_storage_size.is_just:
+            res["NEW_AUTO_TEST_MAX_STORAGE_SIZE"] = to_dict(
+                self.new_auto_test_max_storage_size.value
+            )
+        if self.new_auto_test_max_file_size.is_just:
+            res["NEW_AUTO_TEST_MAX_FILE_SIZE"] = to_dict(
+                self.new_auto_test_max_file_size.value
+            )
+        if self.new_auto_test_build_output_limit.is_just:
+            res["NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT"] = to_dict(
+                self.new_auto_test_build_output_limit.value
+            )
+        if self.new_auto_test_test_output_limit.is_just:
+            res["NEW_AUTO_TEST_TEST_OUTPUT_LIMIT"] = to_dict(
+                self.new_auto_test_test_output_limit.value
+            )
+        if self.new_auto_test_initial_build_id.is_just:
+            res["NEW_AUTO_TEST_INITIAL_BUILD_ID"] = to_dict(
+                self.new_auto_test_initial_build_id.value
+            )
+        if self.new_auto_test_build_max_command_time.is_just:
+            res["NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME"] = to_dict(
+                self.new_auto_test_build_max_command_time.value
+            )
+        if self.new_auto_test_test_max_command_time.is_just:
+            res["NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME"] = to_dict(
+                self.new_auto_test_test_max_command_time.value
+            )
         if self.exam_login_max_length.is_just:
             res["EXAM_LOGIN_MAX_LENGTH"] = to_dict(
                 self.exam_login_max_length.value
@@ -1214,6 +1534,10 @@ class PartialAllSiteSettings:
             )
         if self.rubrics_enabled.is_just:
             res["RUBRICS_ENABLED"] = to_dict(self.rubrics_enabled.value)
+        if self.rubric_enabled_for_teacher_on_submissions_page.is_just:
+            res["RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE"] = to_dict(
+                self.rubric_enabled_for_teacher_on_submissions_page.value
+            )
         if self.automatic_lti_role_enabled.is_just:
             res["AUTOMATIC_LTI_ROLE_ENABLED"] = to_dict(
                 self.automatic_lti_role_enabled.value
@@ -1258,6 +1582,10 @@ class PartialAllSiteSettings:
             )
         if self.editor_enabled.is_just:
             res["EDITOR_ENABLED"] = to_dict(self.editor_enabled.value)
+        if self.new_auto_test_enabled.is_just:
+            res["NEW_AUTO_TEST_ENABLED"] = to_dict(
+                self.new_auto_test_enabled.value
+            )
         if self.server_time_correction_enabled.is_just:
             res["SERVER_TIME_CORRECTION_ENABLED"] = to_dict(
                 self.server_time_correction_enabled.value
@@ -1270,6 +1598,10 @@ class PartialAllSiteSettings:
             res["GRADING_NOTIFICATIONS_ENABLED"] = to_dict(
                 self.grading_notifications_enabled.value
             )
+        if self.sso_username_decollision_enabled.is_just:
+            res["SSO_USERNAME_DECOLLISION_ENABLED"] = to_dict(
+                self.sso_username_decollision_enabled.value
+            )
         if self.feedback_threads_initially_collapsed.is_just:
             res["FEEDBACK_THREADS_INITIALLY_COLLAPSED"] = to_dict(
                 self.feedback_threads_initially_collapsed.value
@@ -1354,6 +1686,42 @@ class PartialAllSiteSettings:
             res["ASSIGNMENT_MAX_POINTS_ENABLED"] = to_dict(
                 self.assignment_max_points_enabled.value
             )
+        if self.course_gradebook_enabled.is_just:
+            res["COURSE_GRADEBOOK_ENABLED"] = to_dict(
+                self.course_gradebook_enabled.value
+            )
+        if self.assignment_description_enabled.is_just:
+            res["ASSIGNMENT_DESCRIPTION_ENABLED"] = to_dict(
+                self.assignment_description_enabled.value
+            )
+        if self.course_gradebook_render_warning_size.is_just:
+            res["COURSE_GRADEBOOK_RENDER_WARNING_SIZE"] = to_dict(
+                self.course_gradebook_render_warning_size.value
+            )
+        if self.course_bulk_register_enabled.is_just:
+            res["COURSE_BULK_REGISTER_ENABLED"] = to_dict(
+                self.course_bulk_register_enabled.value
+            )
+        if self.csv_large_file_limit.is_just:
+            res["CSV_LARGE_FILE_LIMIT"] = to_dict(
+                self.csv_large_file_limit.value
+            )
+        if self.csv_too_many_errors_limit.is_just:
+            res["CSV_TOO_MANY_ERRORS_LIMIT"] = to_dict(
+                self.csv_too_many_errors_limit.value
+            )
+        if self.new_auto_test_copying_enabled.is_just:
+            res["NEW_AUTO_TEST_COPYING_ENABLED"] = to_dict(
+                self.new_auto_test_copying_enabled.value
+            )
+        if self.new_auto_test_old_submission_age.is_just:
+            res["NEW_AUTO_TEST_OLD_SUBMISSION_AGE"] = to_dict(
+                self.new_auto_test_old_submission_age.value
+            )
+        if self.canvas_course_id_copying_enabled.is_just:
+            res["CANVAS_COURSE_ID_COPYING_ENABLED"] = to_dict(
+                self.canvas_course_id_copying_enabled.value
+            )
         return res
 
     @classmethod
@@ -1377,6 +1745,14 @@ class PartialAllSiteSettings:
             auto_test_code_quality_message=parsed.AUTO_TEST_CODE_QUALITY_MESSAGE,
             auto_test_max_result_not_started=parsed.AUTO_TEST_MAX_RESULT_NOT_STARTED,
             auto_test_max_unit_test_metadata_length=parsed.AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH,
+            new_auto_test_max_dynamodb_size=parsed.NEW_AUTO_TEST_MAX_DYNAMODB_SIZE,
+            new_auto_test_max_storage_size=parsed.NEW_AUTO_TEST_MAX_STORAGE_SIZE,
+            new_auto_test_max_file_size=parsed.NEW_AUTO_TEST_MAX_FILE_SIZE,
+            new_auto_test_build_output_limit=parsed.NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT,
+            new_auto_test_test_output_limit=parsed.NEW_AUTO_TEST_TEST_OUTPUT_LIMIT,
+            new_auto_test_initial_build_id=parsed.NEW_AUTO_TEST_INITIAL_BUILD_ID,
+            new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
+            new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
             exam_login_max_length=parsed.EXAM_LOGIN_MAX_LENGTH,
             login_token_before_time=parsed.LOGIN_TOKEN_BEFORE_TIME,
             min_password_score=parsed.MIN_PASSWORD_SCORE,
@@ -1401,6 +1777,7 @@ class PartialAllSiteSettings:
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
+            rubric_enabled_for_teacher_on_submissions_page=parsed.RUBRIC_ENABLED_FOR_TEACHER_ON_SUBMISSIONS_PAGE,
             automatic_lti_role_enabled=parsed.AUTOMATIC_LTI_ROLE_ENABLED,
             lti_enabled=parsed.LTI_ENABLED,
             linters_enabled=parsed.LINTERS_ENABLED,
@@ -1415,9 +1792,11 @@ class PartialAllSiteSettings:
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
             editor_enabled=parsed.EDITOR_ENABLED,
+            new_auto_test_enabled=parsed.NEW_AUTO_TEST_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
             grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
+            sso_username_decollision_enabled=parsed.SSO_USERNAME_DECOLLISION_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
             max_user_setting_amount=parsed.MAX_USER_SETTING_AMOUNT,
             send_registration_email=parsed.SEND_REGISTRATION_EMAIL,
@@ -1439,6 +1818,15 @@ class PartialAllSiteSettings:
             assignment_point_decimals=parsed.ASSIGNMENT_POINT_DECIMALS,
             lti_lock_date_copying_enabled=parsed.LTI_LOCK_DATE_COPYING_ENABLED,
             assignment_max_points_enabled=parsed.ASSIGNMENT_MAX_POINTS_ENABLED,
+            course_gradebook_enabled=parsed.COURSE_GRADEBOOK_ENABLED,
+            assignment_description_enabled=parsed.ASSIGNMENT_DESCRIPTION_ENABLED,
+            course_gradebook_render_warning_size=parsed.COURSE_GRADEBOOK_RENDER_WARNING_SIZE,
+            course_bulk_register_enabled=parsed.COURSE_BULK_REGISTER_ENABLED,
+            csv_large_file_limit=parsed.CSV_LARGE_FILE_LIMIT,
+            csv_too_many_errors_limit=parsed.CSV_TOO_MANY_ERRORS_LIMIT,
+            new_auto_test_copying_enabled=parsed.NEW_AUTO_TEST_COPYING_ENABLED,
+            new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
+            canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
         )
         res.raw_data = d
         return res
