@@ -13,6 +13,9 @@ from ..utils import to_dict
 from .assignment_default_grading_scale_setting import (
     AssignmentDefaultGradingScaleSetting,
 )
+from .assignment_description_enabled_setting import (
+    AssignmentDescriptionEnabledSetting,
+)
 from .assignment_max_points_enabled_setting import (
     AssignmentMaxPointsEnabledSetting,
 )
@@ -71,7 +74,19 @@ from .automatic_lti_role_enabled_setting import AutomaticLtiRoleEnabledSetting
 from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
 )
+from .canvas_course_id_copying_enabled_setting import (
+    CanvasCourseIdCopyingEnabledSetting,
+)
+from .course_bulk_register_enabled_setting import (
+    CourseBulkRegisterEnabledSetting,
+)
+from .course_gradebook_enabled_setting import CourseGradebookEnabledSetting
+from .course_gradebook_render_warning_size_setting import (
+    CourseGradebookRenderWarningSizeSetting,
+)
 from .course_register_enabled_setting import CourseRegisterEnabledSetting
+from .csv_large_file_limit_setting import CsvLargeFileLimitSetting
+from .csv_too_many_errors_limit_setting import CsvTooManyErrorsLimitSetting
 from .editor_enabled_setting import EditorEnabledSetting
 from .email_students_enabled_setting import EmailStudentsEnabledSetting
 from .exam_login_max_length_setting import ExamLoginMaxLengthSetting
@@ -126,12 +141,44 @@ from .metric_gathering_time_interval_setting import (
     MetricGatheringTimeIntervalSetting,
 )
 from .min_password_score_setting import MinPasswordScoreSetting
+from .new_auto_test_build_max_command_time_setting import (
+    NewAutoTestBuildMaxCommandTimeSetting,
+)
+from .new_auto_test_build_output_limit_setting import (
+    NewAutoTestBuildOutputLimitSetting,
+)
+from .new_auto_test_copying_enabled_setting import (
+    NewAutoTestCopyingEnabledSetting,
+)
+from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
+from .new_auto_test_initial_build_id_setting import (
+    NewAutoTestInitialBuildIdSetting,
+)
+from .new_auto_test_max_dynamodb_size_setting import (
+    NewAutoTestMaxDynamodbSizeSetting,
+)
+from .new_auto_test_max_file_size_setting import NewAutoTestMaxFileSizeSetting
+from .new_auto_test_max_storage_size_setting import (
+    NewAutoTestMaxStorageSizeSetting,
+)
+from .new_auto_test_old_submission_age_setting import (
+    NewAutoTestOldSubmissionAgeSetting,
+)
+from .new_auto_test_test_max_command_time_setting import (
+    NewAutoTestTestMaxCommandTimeSetting,
+)
+from .new_auto_test_test_output_limit_setting import (
+    NewAutoTestTestOutputLimitSetting,
+)
 from .notification_poll_time_setting import NotificationPollTimeSetting
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
 from .register_enabled_setting import RegisterEnabledSetting
 from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
 from .reset_token_time_setting import ResetTokenTimeSetting
+from .rubric_enabled_for_teacher_on_submissions_page_setting import (
+    RubricEnabledForTeacherOnSubmissionsPageSetting,
+)
 from .rubrics_enabled_setting import RubricsEnabledSetting
 from .send_registration_email_setting import SendRegistrationEmailSetting
 from .server_time_correction_enabled_setting import (
@@ -141,6 +188,9 @@ from .server_time_diff_tolerance_setting import ServerTimeDiffToleranceSetting
 from .server_time_sync_interval_setting import ServerTimeSyncIntervalSetting
 from .setting_token_time_setting import SettingTokenTimeSetting
 from .site_email_setting import SiteEmailSetting
+from .sso_username_decollision_enabled_setting import (
+    SsoUsernameDecollisionEnabledSetting,
+)
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
 from .tour_configurations_setting import TourConfigurationsSetting
 from .tour_polling_interval_setting import TourPollingIntervalSetting
@@ -160,6 +210,14 @@ SiteSettingInput = t.Union[
     AutoTestCodeQualityMessageSetting,
     AutoTestMaxResultNotStartedSetting,
     AutoTestMaxUnitTestMetadataLengthSetting,
+    NewAutoTestMaxDynamodbSizeSetting,
+    NewAutoTestMaxStorageSizeSetting,
+    NewAutoTestMaxFileSizeSetting,
+    NewAutoTestBuildOutputLimitSetting,
+    NewAutoTestTestOutputLimitSetting,
+    NewAutoTestInitialBuildIdSetting,
+    NewAutoTestBuildMaxCommandTimeSetting,
+    NewAutoTestTestMaxCommandTimeSetting,
     ExamLoginMaxLengthSetting,
     LoginTokenBeforeTimeSetting,
     MinPasswordScoreSetting,
@@ -184,6 +242,7 @@ SiteSettingInput = t.Union[
     AssignmentDefaultGradingScaleSetting,
     BlackboardZipUploadEnabledSetting,
     RubricsEnabledSetting,
+    RubricEnabledForTeacherOnSubmissionsPageSetting,
     AutomaticLtiRoleEnabledSetting,
     LtiEnabledSetting,
     LintersEnabledSetting,
@@ -198,9 +257,11 @@ SiteSettingInput = t.Union[
     AtImageCachingEnabledSetting,
     StudentPaymentEnabledSetting,
     EditorEnabledSetting,
+    NewAutoTestEnabledSetting,
     ServerTimeCorrectionEnabledSetting,
     MetricGatheringEnabledSetting,
     GradingNotificationsEnabledSetting,
+    SsoUsernameDecollisionEnabledSetting,
     FeedbackThreadsInitiallyCollapsedSetting,
     MaxUserSettingAmountSetting,
     SendRegistrationEmailSetting,
@@ -222,6 +283,15 @@ SiteSettingInput = t.Union[
     AssignmentPointDecimalsSetting,
     LtiLockDateCopyingEnabledSetting,
     AssignmentMaxPointsEnabledSetting,
+    CourseGradebookEnabledSetting,
+    AssignmentDescriptionEnabledSetting,
+    CourseGradebookRenderWarningSizeSetting,
+    CourseBulkRegisterEnabledSetting,
+    CsvLargeFileLimitSetting,
+    CsvTooManyErrorsLimitSetting,
+    NewAutoTestCopyingEnabledSetting,
+    NewAutoTestOldSubmissionAgeSetting,
+    CanvasCourseIdCopyingEnabledSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -239,6 +309,14 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AutoTestCodeQualityMessageSetting),
         ParserFor.make(AutoTestMaxResultNotStartedSetting),
         ParserFor.make(AutoTestMaxUnitTestMetadataLengthSetting),
+        ParserFor.make(NewAutoTestMaxDynamodbSizeSetting),
+        ParserFor.make(NewAutoTestMaxStorageSizeSetting),
+        ParserFor.make(NewAutoTestMaxFileSizeSetting),
+        ParserFor.make(NewAutoTestBuildOutputLimitSetting),
+        ParserFor.make(NewAutoTestTestOutputLimitSetting),
+        ParserFor.make(NewAutoTestInitialBuildIdSetting),
+        ParserFor.make(NewAutoTestBuildMaxCommandTimeSetting),
+        ParserFor.make(NewAutoTestTestMaxCommandTimeSetting),
         ParserFor.make(ExamLoginMaxLengthSetting),
         ParserFor.make(LoginTokenBeforeTimeSetting),
         ParserFor.make(MinPasswordScoreSetting),
@@ -263,6 +341,7 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AssignmentDefaultGradingScaleSetting),
         ParserFor.make(BlackboardZipUploadEnabledSetting),
         ParserFor.make(RubricsEnabledSetting),
+        ParserFor.make(RubricEnabledForTeacherOnSubmissionsPageSetting),
         ParserFor.make(AutomaticLtiRoleEnabledSetting),
         ParserFor.make(LtiEnabledSetting),
         ParserFor.make(LintersEnabledSetting),
@@ -277,9 +356,11 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AtImageCachingEnabledSetting),
         ParserFor.make(StudentPaymentEnabledSetting),
         ParserFor.make(EditorEnabledSetting),
+        ParserFor.make(NewAutoTestEnabledSetting),
         ParserFor.make(ServerTimeCorrectionEnabledSetting),
         ParserFor.make(MetricGatheringEnabledSetting),
         ParserFor.make(GradingNotificationsEnabledSetting),
+        ParserFor.make(SsoUsernameDecollisionEnabledSetting),
         ParserFor.make(FeedbackThreadsInitiallyCollapsedSetting),
         ParserFor.make(MaxUserSettingAmountSetting),
         ParserFor.make(SendRegistrationEmailSetting),
@@ -301,5 +382,14 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AssignmentPointDecimalsSetting),
         ParserFor.make(LtiLockDateCopyingEnabledSetting),
         ParserFor.make(AssignmentMaxPointsEnabledSetting),
+        ParserFor.make(CourseGradebookEnabledSetting),
+        ParserFor.make(AssignmentDescriptionEnabledSetting),
+        ParserFor.make(CourseGradebookRenderWarningSizeSetting),
+        ParserFor.make(CourseBulkRegisterEnabledSetting),
+        ParserFor.make(CsvLargeFileLimitSetting),
+        ParserFor.make(CsvTooManyErrorsLimitSetting),
+        ParserFor.make(NewAutoTestCopyingEnabledSetting),
+        ParserFor.make(NewAutoTestOldSubmissionAgeSetting),
+        ParserFor.make(CanvasCourseIdCopyingEnabledSetting),
     ),
 )
